@@ -3,21 +3,13 @@ use sscanf::*;
 
 #[test]
 fn hex_number() {
-    let input = "0xaAbBcC"; // split because HexNumber uses usize which might be 32 or 64 bits
+    let input = "0xaAbBcCdDeEfF";
     let output = sscanf!(input, "{}", HexNumber).unwrap();
-    assert_eq!(output, 0xaabbcc);
+    assert_eq!(output, 0xaabbccddeeff);
 
-    let input = "0xdDeEfF";
+    let input = "0x1234567890";
     let output = sscanf!(input, "{}", HexNumber).unwrap();
-    assert_eq!(output, 0xddeeff);
-
-    let input = "0x12345";
-    let output = sscanf!(input, "{}", HexNumber).unwrap();
-    assert_eq!(output, 0x12345);
-
-    let input = "0x67890";
-    let output = sscanf!(input, "{}", HexNumber).unwrap();
-    assert_eq!(output, 0x67890);
+    assert_eq!(output, 0x1234567890);
 
     let input = "10x20XA";
     let output = sscanf!(input, "{}{}{}", HexNumber, HexNumber, HexNumber).unwrap();
